@@ -53,7 +53,7 @@ def debug_response(response, browser_traceback=True, msg="", display_tb=True):
     url = response.request["PATH_INFO"]
 
     stack_info = get_stack_info(filepath_filter="django_tools")
-    stack_info.append(escape(msg))
+    stack_info.append(msg)
     if display_tb:
         print
         print "debug_response:"
@@ -61,7 +61,7 @@ def debug_response(response, browser_traceback=True, msg="", display_tb=True):
         print "\n".join(stack_info)
         print "-" * 80
 
-    stack_info = "".join(stack_info)
+    stack_info = escape("".join(stack_info))
 
     response_info = "<dl>\n"
 
